Package: cascadeSelect
Title: A Cascade Select Input for 'Shiny'
Version: 1.1.0
Authors@R: c(
    person("Stéphane", "Laurent", , "laurent_step@outlook.fr", role = c("aut", "cre")),
    person("PrimeTek", "Informatics", role = "cph",
           comment = "PrimeReact library")
  )
Description: Provides a cascade select widget for usage in 'Shiny'
    applications. This is useful for selection of hierarchical choices
    (e.g. continent, country, city). It is taken from the 'JavaScript'
    library 'PrimeReact'.
License: GPL-3
Depends: R (>= 2.10)
Imports: fontawesome, grDevices, htmltools, reactR, shiny, tools
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.2.3
URL: https://github.com/stla/cascadeSelect
BugReports: https://github.com/stla/cascadeSelect/issues
NeedsCompilation: no
Packaged: 2023-06-15 05:33:55 UTC; SDL96354
Author: Stéphane Laurent [aut, cre],
  PrimeTek Informatics [cph] (PrimeReact library)
Maintainer: Stéphane Laurent <laurent_step@outlook.fr>
Repository: CRAN
Date/Publication: 2023-06-15 06:00:02 UTC
Built: R 4.6.0; ; 2026-04-28 15:16:08 UTC; unix
