# cascadeSelect

<!-- badges: start -->
[![R-CMD-check](https://github.com/stla/cascadeSelect/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/stla/cascadeSelect/actions/workflows/R-CMD-check.yaml)
<!-- badges: end -->

___

![](https://raw.githubusercontent.com/stla/cascadeSelect/main/inst/gifs/essai01.gif)
