countries <- list(

  list(
    name = "Australia",
    states = list(
      list(
        name = "New South Wales",
        cities = list(
          list(
            cname = "Sydney", code = "A-SY"
          ),
          list(
            cname = "Newcastle", code = "A-NE"
          ),
          list(
            cname = "Wollongong", code = "A-WO"
          )
        )
      ),
      list(
        name = "Queensland",
        cities = list(
          list(
            cname = "Brisbane", code = "A-BR"
          ),
          list(
            cname = "Townsville", code = "A-TO"
          )
        )
      )
    )
  ),

  list(
    name = "Canada",
    states = list(
      list(
        name = "Quebec",
        cities = list(
          list(
            cname = "Montreal", code = "C-MO"
          ),
          list(
            cname = "Quebec City", code = "C-QU"
          )
        )
      ),
      list(
        name = "Ontario",
        cities = list(
          list(
            cname = "Ottawa", code = "C-OT"
          ),
          list(
            cname = "Toronto", code = "C-TO"
          )
        )
      )
    )
  ),

  list(
    name = "United states",
    states = list(
      list(
        name = "California",
        cities = list(
          list(
            cname = "Los Angeles", code = "US-LA"
          ),
          list(
            cname = "San Diego", code = "US-SD"
          ),
          list(
            cname = "San Francisco", code = "US-SF"
          )
        )
      ),
      list(
        name = "Florida",
        cities = list(
          list(
            cname = "Jacksonville", code = "US-JA"
          ),
          list(
            cname = "Miami", code = "US-MI"
          ),
          list(
            cname = "Tampa", code = "US-TA"
          ),
          list(
            cname = "Orlando", code = "US-OR"
          )
        )
      ),
      list(
        name = "Texas",
        cities = list(
          list(
            cname = "Austin", code = "US-AU"
          ),
          list(
            cname = "Dallas", code = "US-DA"
          ),
          list(
            cname = "Houston", code = "US-HO"
          )
        )
      )
    )
  )
)
