pi_icons <- c(
  "align-center",
  "align-justify",
  "align-left",
  "align-right",
  "android",
  "angle-double-down",
  "angle-double-left",
  "angle-double-right",
  "angle-double-up",
  "angle-down",
  "angle-left",
  "angle-right",
  "angle-up",
  "apple",
  "arrow-circle-down",
  "arrow-circle-left",
  "arrow-circle-right",
  "arrow-circle-up",
  "arrow-down-left",
  "arrow-down-right",
  "arrow-down",
  "arrow-left",
  "arrow-right-arrow-left",
  "arrow-right",
  "arrows-alt",
  "arrows-h",
  "arrows-v",
  "arrow-up-left",
  "arrow-up-right",
  "arrow-up",
  "at",
  "backward",
  "ban",
  "bars",
  "bell",
  "bitcoin",
  "bolt",
  "bookmark-fill",
  "bookmark",
  "book",
  "box",
  "briefcase",
  "building",
  "calculator",
  "calendar-minus",
  "calendar-plus",
  "calendar",
  "calendar-times",
  "camera",
  "caret-down",
  "caret-left",
  "caret-right",
  "caret-up",
  "car",
  "cart-plus",
  "chart-bar",
  "chart-line",
  "chart-pie",
  "check-circle",
  "check-square",
  "check",
  "chevron-circle-down",
  "chevron-circle-left",
  "chevron-circle-right",
  "chevron-circle-up",
  "chevron-down",
  "chevron-left",
  "chevron-right",
  "chevron-up",
  "circle-fill",
  "circle-off",
  "circle-on",
  "circle",
  "clock",
  "clone",
  "cloud-download",
  "cloud",
  "cloud-upload",
  "code",
  "cog",
  "comments",
  "comment",
  "compass",
  "copy",
  "credit-card",
  "database",
  "delete-left",
  "desktop",
  "directions-alt",
  "directions",
  "discord",
  "dollar",
  "download",
  "eject",
  "ellipsis-h",
  "ellipsis-v",
  "envelope",
  "eraser",
  "euro",
  "exclamation-circle",
  "exclamation-triangle",
  "external-link",
  "eye-slash",
  "eye",
  "facebook",
  "fast-backward",
  "fast-forward",
  "file-edit",
  "file-excel",
  "file-export",
  "file-import",
  "file-o",
  "file-pdf",
  "file",
  "file-word",
  "filter-fill",
  "filter-slash",
  "filter",
  "flag-fill",
  "flag",
  "folder-open",
  "folder",
  "forward",
  "gift",
  "github",
  "globe",
  "google",
  "hashtag",
  "heart-fill",
  "heart",
  "history",
  "home",
  "hourglass",
  "id-card",
  "images",
  "image",
  "inbox",
  "info-circle",
  "info",
  "instagram",
  "key",
  "language",
  "linkedin",
  "link",
  "list",
  "lock-open",
  "lock",
  "map-marker",
  "map",
  "megaphone",
  "microphone",
  "microsoft",
  "minus-circle",
  "minus",
  "mobile",
  "money-bill",
  "moon",
  "palette",
  "paperclip",
  "pause",
  "paypal",
  "pencil",
  "percentage",
  "phone",
  "play",
  "plus-circle",
  "plus",
  "pound",
  "power-off",
  "prime",
  "print",
  "qrcode",
  "question-circle",
  "question",
  "reddit",
  "refresh",
  "replay",
  "reply",
  "save",
  "search-minus",
  "search-plus",
  "search",
  "send",
  "server",
  "share-alt",
  "shield",
  "shopping-bag",
  "shopping-cart",
  "sign-in",
  "sign-out",
  "sitemap",
  "slack",
  "sliders-h",
  "sliders-v",
  "sort-alpha-alt-down",
  "sort-alpha-alt-up",
  "sort-alpha-down",
  "sort-alpha-up",
  "sort-alt-slash",
  "sort-alt",
  "sort-amount-down-alt",
  "sort-amount-down",
  "sort-amount-up-alt",
  "sort-amount-up",
  "sort-down",
  "sort-numeric-alt-down",
  "sort-numeric-alt-up",
  "sort-numeric-down",
  "sort-numeric-up",
  "sort",
  "sort-up",
  "spinner",
  "star-fill",
  "star",
  "step-backward-alt",
  "step-backward",
  "step-forward-alt",
  "step-forward",
  "stop-circle",
  "stop",
  "stopwatch",
  "sun",
  "sync",
  "table",
  "tablet",
  "tags",
  "tag",
  "telegram",
  "th-large",
  "thumbs-down-fill",
  "thumbs-down",
  "thumbs-up-fill",
  "thumbs-up",
  "ticket",
  "times-circle",
  "times",
  "trash",
  "truck",
  "twitter",
  "undo",
  "unlock",
  "upload",
  "user-edit",
  "user-minus",
  "user-plus",
  "users",
  "user",
  "verified",
  "video",
  "vimeo",
  "volume-down",
  "volume-off",
  "volume-up",
  "wallet",
  "whatsapp",
  "wifi",
  "window-maximize",
  "window-minimize",
  "wrench",
  "youtube"
)
